@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.019_01';
+our $VERSION = '0.019_02';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -271,10 +271,17 @@ sub _keyword {
 
     $! = 0;
     chomp ( my $pcdata = capture_merged { system( $command ) } );
-    croak "Could not call pkg-config: $!" if $!;
+
+    # if pkg-config fails for whatever reason, then we try to
+    # fallback on alien_provides_*
+    $pcdata = '' if $! || $?;
 
     $pcdata =~ s/\s*$//;
 
+    if(my $system_provides = $self->config('system_provides')->{$keyword}) {
+      $pcdata = length $pcdata ? "$pcdata $system_provides" : $system_provides;
+    }
+
     return $pcdata;
   }
 
